/*

 This example  prints the Wifi shield's MAC address, and
 scans for available Wifi networks using the Wifi shield.
 Every ten seconds, it scans again. It doesn't actually
 connect to any network, so no encryption scheme is specified.

 Circuit:
 * WiFi shield attached

 created 13 July 2010
 by dlf (Metodo2 srl)
 modified 21 Junn 2012
 by Tom Igoe and Jaymes Dec
 */
#include "SPI.h"
#include "AmebaILI9341.h"
#define TFT_RESET       PA27
#define TFT_DC          PB3
#define TFT_CS          PA15

#include <WiFi.h>

AmebaILI9341 tft = AmebaILI9341(TFT_CS, TFT_DC, TFT_RESET);

#define ILI9341_SPI_FREQUENCY 20000000

void setup() {
    //Initialize serial and wait for port to open:
    Serial.begin(115200);
    while (!Serial) {
        ; // wait for serial port to connect. Needed for native USB port only
    }
    SPI.setDefaultFrequency(ILI9341_SPI_FREQUENCY);

    tft.begin();

    Serial.println("test filling screen");
    testFillScreen();
    delay(500);

    tft.clr();

    tft.setCursor(0, 0);
    tft.setForeground(ILI9341_WHITE);
    tft.setBackground(ILI9341_NAVY);
    tft.setFontSize(2);
    tft.setRotation(1);
    tft.println("Ameba WiFi Scanner        ");
    tft.setBackground(ILI9341_BLACK);
    
    
    // check for the presence of the shield:
    if (WiFi.status() == WL_NO_SHIELD) {
        Serial.println("WiFi shield not present");
        // don't continue:
        while (true);
    }

    // Print WiFi MAC address:
    printMacAddress();

    // scan for existing networks:
    Serial.println("Scanning available networks...");
    listNetworks();
}

void loop() {
    //delay(10000);
}

void printMacAddress() {
    // the MAC address of your Wifi shield
    byte mac[6];

    tft.setForeground(ILI9341_YELLOW);
    tft.setFontSize(1);
    tft.println("MAC Address:");
    // print your MAC address:
    WiFi.macAddress(mac);
    Serial.print("MAC: ");
    Serial.print(mac[0], HEX);
    tft.print(mac[0], HEX);
    tft.print(":");
    Serial.print(":");
    Serial.print(mac[1], HEX);
    tft.print(mac[1], HEX);
    tft.print(":");
    Serial.print(":");
    Serial.print(mac[2], HEX);
    tft.print(mac[2], HEX);
    tft.print(":");
    Serial.print(":");
    Serial.print(mac[3], HEX);
    tft.print(mac[3], HEX);
    tft.print(":");
    Serial.print(":");
    Serial.print(mac[4], HEX);
    tft.print(mac[4], HEX);
    tft.print(":");
    Serial.print(":");
    Serial.println(mac[5], HEX);
    tft.println(mac[5], HEX);
    tft.println();
}

void listNetworks() {
    // scan for nearby networks:
    Serial.println("** Scan Networks **");
    int numSsid = WiFi.scanNetworks();
    if (numSsid == -1) {
        Serial.println("Couldn't get a wifi connection");
        while (true);
    }

    tft.setForeground(ILI9341_CYAN);
    // print the list of networks seen:
    Serial.print("number of available networks:");
    Serial.println(numSsid);
    tft.print("Number of WiFi found:");
    tft.println(numSsid);
    tft.println();

    // print the network number and name for each network found:
    for (int thisNet = 0; thisNet < numSsid; thisNet++) {
        Serial.print(thisNet);
        tft.print(thisNet);
        Serial.print(") ");
        tft.print(") ");
        Serial.print(WiFi.SSID(thisNet));
        tft.print(WiFi.SSID(thisNet));
        tft.print(" : ");
        Serial.print("\tSignal: ");
        Serial.print(WiFi.RSSI(thisNet));
        tft.print(WiFi.RSSI(thisNet));
        Serial.print(" dBm");
        tft.print(" dBm");
        Serial.print("\tEncryptionRaw: ");
        tft.print(", ");
        printEncryptionTypeEx(WiFi.encryptionTypeEx(thisNet));
        Serial.print("\tEncryption: ");
        printEncryptionType(WiFi.encryptionType(thisNet));
    }
}

void printEncryptionTypeEx(uint32_t thisType) {
    /*  Arduino wifi api use encryption type to mapping to security type.
    *  This function demonstrate how to get more richful information of security type.
    */
    switch (thisType) {
        case SECURITY_OPEN:
            Serial.print("Open");
            break;
        case SECURITY_WEP_PSK:
            Serial.print("WEP");
            break;
        case SECURITY_WPA_TKIP_PSK:
            Serial.print("WPA TKIP");
            break;
        case SECURITY_WPA_AES_PSK:
            Serial.print("WPA AES");
            break;
        case SECURITY_WPA2_AES_PSK:
            Serial.print("WPA2 AES");
            break;
        case SECURITY_WPA2_TKIP_PSK:
            Serial.print("WPA2 TKIP");
            break;
        case SECURITY_WPA2_MIXED_PSK:
            Serial.print("WPA2 Mixed");
            break;
        case SECURITY_WPA_WPA2_MIXED:
            Serial.print("WPA/WPA2 AES");
            break;
    }
}

void printEncryptionType(int thisType) {
    // read the encryption type and print out the name:
    switch (thisType) {
        case ENC_TYPE_WEP:
            Serial.println("WEP");
            tft.println("WEP");
            break;
        case ENC_TYPE_TKIP:
            Serial.println("WPA");
            tft.println("WPA");
            break;
        case ENC_TYPE_CCMP:
            Serial.println("WPA2");
            tft.println("WPA2");
            break;
        case ENC_TYPE_NONE:
            Serial.println("None");
            tft.println("None");
            break;
        case ENC_TYPE_AUTO:
            Serial.println("Auto");
            tft.println("Auto");
            break;
    }
}

unsigned long testFillScreen() {
    tft.fillScreen(ILI9341_BLACK);
    tft.fillScreen(ILI9341_RED);
    tft.fillScreen(ILI9341_GREEN);
    tft.fillScreen(ILI9341_BLUE);
    tft.fillScreen(ILI9341_BLACK);

    return 0;
}
